package Plack::Auth::SSO::ResponseParser;

use strict;
use Moo::Role;

our $VERSION = "0.013";

requires "parse";

1;
